===================
Authors and Credits
===================

If we have neglected to include you, please let us know right away!

* Kyle Barbary
* Larry Bradley
* Christoph Deil
* Demitri Muna
* Thomas Robitaille
* Erik Tollerud
* Benjamin Alan Weaver
